summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHyotaek Shim <hyotaek.shim@samsung.com>2019-02-28 16:38:13 +0900
committerHyotaek Shim <hyotaek.shim@samsung.com>2019-02-28 16:39:47 +0900
commitd42b192791de8b7b4ef650bcea307c5501f85e5c (patch)
tree8868abb719bb91ca9ffd43540c608f70812ea462
parentb27c0d29aff919b34ec17a59411fff789aa6017e (diff)
downloadlibsvi-d42b192791de8b7b4ef650bcea307c5501f85e5c.tar.gz
libsvi-d42b192791de8b7b4ef650bcea307c5501f85e5c.tar.bz2
libsvi-d42b192791de8b7b4ef650bcea307c5501f85e5c.zip
Add a new ids range for IoT devices
Change-Id: Ie5bf43c158b87afc27b16e0a13fb6191e1dbcb59 Signed-off-by: Hyotaek Shim <hyotaek.shim@samsung.com>
-rwxr-xr-xinclude/feedback-ids-internal.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/feedback-ids-internal.h b/include/feedback-ids-internal.h
index 2c45215..74c668e 100755
--- a/include/feedback-ids-internal.h
+++ b/include/feedback-ids-internal.h
@@ -64,14 +64,15 @@ typedef enum {
FEEDBACK_PATTERN_NOTIFICATION = 146, /**< Feedback pattern for notification */
FEEDBACK_PATTERN_RESERVED_END = 10000,
- // Add new pattern ids for mobile and wearable devices here
+ // Add new pattern ids for Mobile and Wearable devices here
// ...
FEEDBACK_PATTERN_MOBILE_END = 20000,
- // Add new pattern ids for tv devices here
+ // Add new pattern ids for TV devices here
// ...
FEEDBACK_PATTERN_TV_END = 30000,
// Add new pattern ids for ivi devices here
// ...
+ FEEDBACK_PATTERN_IOT_END = 40000,
FEEDBACK_PATTERN_INTERNAL_END = 90000,
} feedback_pattern_internal_e;
@@ -64,14 +64,15 @@ typedef enum {
// ...
FEEDBACK_PATTERN_TV_END = 30000,
- // Add new pattern ids for ivi devices here
+ // Add new pattern ids for IoT devices here
// ...